@@ -15,9 +15,11 @@ use WebDAO::Base;
 use CGI;
 use MIME::Base64;
 use Digest::MD5 qw(md5_hex);
+
 use base qw( WebDAO::Session );
+
 use strict 'vars';
-__PACKAGE__->mk_attr ( Cookie_name=>undef, Db_file=>undef );
+__PACKAGE__->attributes qw( Cookie_name Db_file );
 
 sub Init {
 
